@@ -185,7 +185,7 @@ vcov.bayesianVARs_bvar <- function(object, ...){
   M <- ncol(object$Y)
   factors <- dim(object$facload)[2]
   Tobs <- nrow(object$logvar)
-  nsave <- dim(object$facload)[3]
+  nsave <- dim(object$PHI)[3]
 
   dates <- NULL
   if(Tobs==1L){
@@ -1756,7 +1756,7 @@ predict.bayesianVARs_bvar <- function(object, ahead = 1L, each = 1L, stable = TR
 
 
   LPL_subset <- logical(1L)
-  VoI <- integer(1L)
+  VoI <- 1L
   if(!LPL){
     Y_obs <- matrix(nrow = 0, ncol = 0)
   }else{
